@@ -6,7 +6,7 @@
 # change 'tests => 1' to 'tests => last_test_to_print';
 
 use Test;
-BEGIN { plan tests => 2 };
+BEGIN { plan tests => 5 };
 use Net::FTPServer::XferLog;
 ok(1); # If we made it this far, we're ok.
 
@@ -17,9 +17,19 @@ ok(1); # If we made it this far, we're ok.
 
 open T, 'test.xlog' or die $!;
 my $hashref;
-my @xferlog = <T>;
 
-$hashref = Net::FTPServer::XferLog->parse_line($xferlog[$#xferlog]);
-ok($hashref->{filename},'p1774034_11i_zhs.zip');
+
+my @expected = ('FILENAME', 'NAMEFILE', 'file with spaces in it.zip', 'p1774034_11i_zhs.zip');
+
+
+my $i;
+while (<T>)
+{
+    $hashref = Net::FTPServer::XferLog->parse_line($_);
+    ok($hashref->{filename}, $expected[$i++]);
+    warn $hashref->{filename};
+}
+
+
 
 
